summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/kdevdesigner_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/kdevdesigner_part.cpp')
-rw-r--r--kdevdesigner/designer/kdevdesigner_part.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kdevdesigner/designer/kdevdesigner_part.cpp b/kdevdesigner/designer/kdevdesigner_part.cpp
index 55e96244..798b8b6c 100644
--- a/kdevdesigner/designer/kdevdesigner_part.cpp
+++ b/kdevdesigner/designer/kdevdesigner_part.cpp
@@ -236,12 +236,12 @@ void KDevDesignerPart::setupToolsAction( KRadioAction * toggle, TQAction * actio
// It's usually safe to leave the factory code alone.. with the
// notable exception of the KAboutData data
#include <kaboutdata.h>
#include <klocale.h>
-KInstance* KDevDesignerPartFactory::s_instance = 0L;
-KAboutData* KDevDesignerPartFactory::s_about = 0L;
+TDEInstance* KDevDesignerPartFactory::s_instance = 0L;
+TDEAboutData* KDevDesignerPartFactory::s_about = 0L;
KDevDesignerPartFactory::KDevDesignerPartFactory()
: KParts::Factory()
@@ -270,14 +270,14 @@ KParts::Part* KDevDesignerPartFactory::createPartObject( TQWidget *parentWidget,
return obj;
}
-KInstance* KDevDesignerPartFactory::instance()
+TDEInstance* KDevDesignerPartFactory::instance()
{
if( !s_instance )
{
- s_about = new KAboutData("kdevdesignerpart", I18N_NOOP("KDevDesignerPart"), "0.1");
+ s_about = new TDEAboutData("kdevdesignerpart", I18N_NOOP("KDevDesignerPart"), "0.1");
s_about->addAuthor("Alexander Dymo", 0, "cloudtemple@mksat.net");
s_about->addAuthor("Trolltech AS", 0, "info@trolltech.com");
- s_instance = new KInstance(s_about);
+ s_instance = new TDEInstance(s_about);
}
return s_instance;
}
@@ -236,12 +236,12 @@ void KDevDesignerPart::setupToolsAction( KRadioAction * toggle, TQAction * actio
// It's usually safe to leave the factory code alone.. with the
-// notable exception of the KAboutData data
+// notable exception of the TDEAboutData data
#include <kaboutdata.h>
#include <klocale.h>